@@ -153,6 +153,9 @@ func (r *registry) ensureDeployment(appRegistries []string, needServiceAccount b
 		if len(deployment.Spec.Template.Spec.Containers) == 0 {
 			deployment.Spec.Template = r.newPodTemplateSpec(registryCommand, needServiceAccount)
 		} else {
+			// Ensure that the registry image is up to date
+			deployment.Spec.Template.Spec.Containers[0].Image = r.image
+
 			// Update the command passed to the registry to account for packages being added and removed
 			// from Quay
 			deployment.Spec.Template.Spec.Containers[0].Command = registryCommand
@@ -397,7 +400,7 @@ func (r *registry) newPodTemplateSpec(registryCommand []string, needServiceAccou
 								Command: action,
 							},
 						},
-						InitialDelaySeconds: 30,
+						InitialDelaySeconds: 60,
 						FailureThreshold:    10,
 					},
 					LivenessProbe: &core.Probe{
